@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 //Instructions TODO: RIM, SIM, ~RST
 
@@ -501,19 +502,12 @@ _eef_inst_func_xra (eef_addr_t opnd_addr, gchar sec)
 static gint
 _eef_inst_func_cmp_i (eef_addr_t opnd_addr, eef_data_t data)
 {
-  _eef_find_and_set_flags (sys.reg.a);
-
-  sys.flag.s = (sys.reg.a < data);
-
+  /* Patch from Debjit Biswas for CMP bug #579320 */
+  eef_data_t a = sys.reg.a;
+  _eef_flag_check_and_set_c (sys.reg.a, data, '-');
   _eef_flag_check_and_set_aux_c (sys.reg.a, data, '-');
-
-  if (sys.reg.a < data)
-	sys.flag.c = 1, sys.flag.z = 0;
-  else if (sys.reg.a > data)
-	sys.flag.c = 0, sys.flag.z = 0;
-  else
-	sys.flag.c = 0, sys.flag.z = 1;
-
+  a += -1 * data;
+ _eef_find_and_set_flags (a);
   return 0;
 }
 
@@ -936,30 +930,27 @@ _eef_inst_func_38 (eef_addr_t opnd_addr)
 static gint
 _eef_inst_func_39 (eef_addr_t opnd_addr)
 {
-  eef_data_t low;
-  eef_data_t high;
+  eef_data_t ac_low;
+  gboolean c_old;
 
-  low = sys.reg.a & 0x0F;
-  high = sys.reg.a >> 4;
+  c_old = sys.flag.c;
+  ac_low = sys.reg.a & 0x0F;
   
-  if (low > 9 || sys.flag.ac)
+  if (ac_low > 9 || sys.flag.ac)
 	{
-	  sys.reg.a += 6;
-	  if((low + 6) > 9)
-		sys.flag.ac = 1;     
-	  else 
-		sys.flag.ac = 0;
-	}
+    _eef_inst_func_add_i (opnd_addr, 6, '+');
+    sys.flag.c = (sys.flag.c || c_old);
+    sys.flag.ac = 1;
+  }
+
+  if (sys.reg.a > 0x99 || sys.flag.c)
+  {
+    sys.reg.a = sys.reg.a + 0x60;
+    sys.flag.c = 1;
+  }
 
-  if (high > 9 || sys.flag.c)
-	{
-	  sys.reg.a += (6 << 4);
-	  if((high + 6) > 9)
-		sys.flag.c = 1;
-	  else 
-		sys.flag.c = 0;
-	}
   return 0;
+  
 }
 
 static gint
