@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 /* bridge.c is really an uglier code! sorry ;-| */
@@ -218,7 +219,16 @@ If so you're advised to send a copy of your source progam."), addr);
 				  ess_trace_mode_over_stack_cont =
 					eef_regpair_get ('S') + 2;
 				  prev_is_call_instr = FALSE;
-				  return TRUE;
+				  if (break_pt)
+				  {
+					bridge_debug_this_line (addr, ln);
+					return FALSE;
+				  }
+				  else
+				  {
+					return TRUE;  
+				  }
+					
 				}
 
 			  bridge_debug_this_line (addr, ln);
@@ -233,7 +243,17 @@ If so you're advised to send a copy of your source progam."), addr);
 			  bridge_debug_this_line (addr, ln);
 			  return FALSE;
 			}
-		  return TRUE;	/* finish the func */
+			
+			if (break_pt)
+			{
+				bridge_debug_this_line (addr, ln);
+				return FALSE;
+			}
+			else
+			{
+				return TRUE;	/* finish the func */
+			}
+		  
 		}
 	  else if (ess_trace_mode == B_TRACE_OUT)
 		{
@@ -242,7 +262,7 @@ If so you're advised to send a copy of your source progam."), addr);
 			ess_trace_mode_out_callret++;
 		  if (eef_is_ret_instr (eef_get_op_at_addr (prev_addr)))
 			ess_trace_mode_out_callret--;
-		  if (ess_trace_mode_out_callret < 0)
+		  if ((ess_trace_mode_out_callret < 0) || (break_pt))
 			{
 			  bridge_debug_this_line (addr, ln);
 			  return FALSE;
@@ -286,6 +306,7 @@ b_assemble (char *text, guint16 start_addr)
   sys.reg.sph = 0xff;
   sys.reg.spl = 0xff;
   gtk_statusbar_push (GTK_STATUSBAR(statusbar), gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar), SIM_CONTEXT),  _("Assembler: running"));
+  gui_editor_clear_all_highlights (app->editor);
   saved_and_assembled_successfully =
 	eef_asm_assemble (text, start_addr, &ds_source, &ds_memblock);
   gtk_statusbar_pop (GTK_STATUSBAR(statusbar), gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar), SIM_CONTEXT));
