@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -31,6 +32,8 @@
 #include "bridge.h"
 #include "asm-listing.h"
 #include "file-op.h"
+#include "gui-list-memory.h"
+#include "gui-list-io.h"
 
 #define DEFAULT_LOAD_ADDR 0x4200
 
@@ -38,6 +41,7 @@ gint start_addr = 0x4200;
 
 GUIEditor *edit = NULL;
 GtkWidget *wind = NULL;
+GtkWidget *tutorial = NULL;
 GtkWidget *filew = NULL;
 
 gboolean
@@ -125,6 +129,30 @@ on_print_activate (GtkAction * menuitem, gpointer user_data)
   gui_editor_print (app->editor);
 }
 
+void on_font_select_activate (GtkAction * menuitem, gpointer user_data)
+{
+  GtkWidget *font_selection_dialog = NULL;
+  const gchar *font_name = gui_editor_get_font (app->editor);
+  gint action = 0;
+  g_assert (app->editor);
+  font_selection_dialog = gtk_font_selection_dialog_new (_("Select font"));
+  gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (font_selection_dialog), font_name);
+  action = gtk_dialog_run (GTK_DIALOG (font_selection_dialog));
+  switch (action) 
+  {
+    case GTK_RESPONSE_OK:
+      font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (font_selection_dialog));
+      if (font_name)
+      {
+        gui_editor_set_font (app->editor, font_name);
+      }
+      break;
+    default:
+      break;
+  }
+  
+  gtk_widget_destroy(font_selection_dialog);
+}
 
 void
 on_quit1_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -159,6 +187,7 @@ on_io_ports1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   eef_reset_io ();
   gui_view_update_io_mem ();
+  gui_list_io_update ();
 }
 
 
@@ -167,6 +196,7 @@ on_main_memory1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   eef_reset_mem ();
   gui_view_update_io_mem ();
+  gui_list_memory_update ();
 }
 
 
@@ -176,6 +206,8 @@ on_reset_all1_activate (GtkMenuItem * menuitem, gpointer user_data)
   eef_reset_all ();
   gui_view_update_reg_flag (TRUE);
   gui_view_update_io_mem ();
+  gui_list_io_update ();
+  gui_list_memory_update ();
 }
 
 
@@ -329,7 +361,7 @@ on_8085_manual1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_assembler_tutorial1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  gtk_widget_show (create_window_start ());
+  show_tutorial ();
 }
 
 
@@ -386,6 +418,10 @@ entry_to_mm (gchar * entry_name, gchar * spin_name, guint8 * base)
 	}
 
   base[(gint) gtk_spin_button_get_value (sb)] = val;
+  if (!strcmp (entry_name,"main_mem_entry"))
+    gui_list_memory_update_single (gtk_spin_button_get_value_as_int (sb));
+  if (!strcmp (entry_name,"main_io_entry"))
+    gui_list_io_update_single (gtk_spin_button_get_value_as_int (sb));
 }
 
 static void
@@ -553,19 +589,7 @@ on_main_entry_hex_activate (GtkEntry * entry, gpointer user_data)
 void
 on_start_but_tutorial_clicked (GtkButton * button, gpointer user_data)
 {
-  gchar *msg =
-	_("Do the following\n\n\
-1. Read \"asm-guide.txt\" for assembler tutorial\n\
-2. Open \"examples/nqueens.asm\" and simulate it.\n\n\
-Usually these files will be found in your system document directory,\n\
-which can be one of the following\n\n\
-/usr/local/doc/GNUSim8085\n\
-/usr/local/share/doc/GNUSim8085\n\
-/usr/share/doc/GNUSim8085\n\n\
-These files are also available in \"doc\" directory\n\
-of GNUSim8085 source tarball (tar.gz file)\n");
-	
-  gui_app_show_msg (GTK_MESSAGE_INFO, msg);
+  show_tutorial ();
   on_start_but_close_clicked (button, NULL);
 }
 
@@ -586,3 +610,122 @@ on_start_but_close_clicked (GtkButton * button, gpointer user_data)
   swd = lookup_widget (GTK_WIDGET (button), "window_start");
   gtk_widget_destroy (swd);
 }
+
+void
+on_mem_list_start_clicked (GtkButton * button, gpointer user_data)
+{
+  GtkWidget *start_entry;
+  gint start_addr;
+  gchar *text;
+	
+  start_entry = lookup_widget (app->window_main, "mem_list_start");
+  g_assert (start_entry);
+	
+  if (!asm_util_parse_number (text = (gchar *)gtk_entry_get_text (GTK_ENTRY (start_entry)), &start_addr))
+  {
+    gui_app_show_msg (GTK_MESSAGE_INFO, _("Enter a valid number within range (0-65535 or 0h-FFFFh)"));
+    return;
+  }
+  gui_list_memory_set_start (start_addr);
+  gui_list_memory_update ();
+  text[strlen (text)] = 'h';
+  gtk_entry_set_text (GTK_ENTRY (start_entry), text);
+}
+
+void
+on_mem_list_start_changed (GtkEntry *entry, gpointer user_data)
+{
+  gint start_addr;
+  gchar *text;
+  g_assert (entry);
+	
+  if (!asm_util_parse_number (text = (gchar *)gtk_entry_get_text (GTK_ENTRY (entry)),&start_addr))
+  {
+    gui_app_show_msg (GTK_MESSAGE_INFO, _("Enter a valid number within range (0-65535 or 0h-FFFFh)"));
+    return;
+  }
+  gui_list_memory_set_start (start_addr);
+  gui_list_memory_update ();
+  text[strlen (text)] = 'h';
+  gtk_entry_set_text (GTK_ENTRY (entry), text);
+}
+
+void
+on_io_list_start_clicked (GtkButton * button, gpointer user_data)
+{
+  GtkWidget *start_entry;
+  gint start_addr;
+  gchar *text;
+
+  start_entry = lookup_widget (app->window_main, "io_list_start");
+  g_assert (start_entry);
+
+  if (!asm_util_parse_number (text = (gchar *)gtk_entry_get_text (GTK_ENTRY (start_entry)), &start_addr))
+  {
+    gui_app_show_msg (GTK_MESSAGE_INFO, _("Enter a valid number within range (0-255 / 0h-00FFh)"));
+    return;
+  }
+  gui_list_io_set_start (start_addr);
+  gui_list_io_update ();
+  text[strlen (text)] = 'h';
+  gtk_entry_set_text (GTK_ENTRY (start_entry), text);
+}
+
+void
+on_io_list_start_changed (GtkEntry *entry, gpointer user_data)
+{
+  gint start_addr;
+  gchar *text;
+  g_assert (entry);
+
+  if (!asm_util_parse_number (text = (gchar *)gtk_entry_get_text (GTK_ENTRY (entry)),&start_addr))
+  {
+    gui_app_show_msg (GTK_MESSAGE_INFO, _("Enter a valid number within range (0-255 / 0h-00FFh)"));
+    return;
+  }
+  gui_list_io_set_start (start_addr);
+  gui_list_io_update ();
+  text[strlen (text)] = 'h';
+  gtk_entry_set_text (GTK_ENTRY (entry), text);
+}
+
+void
+show_tutorial ()
+{
+  GString* tutorial_text = read_tutorial ();
+  GtkWidget *cont;
+
+  /* show */
+  tutorial = create_window_tutorial ();
+  cont = lookup_widget (tutorial, "tutorial_vbox");
+  g_assert (cont);
+  edit = gui_editor_new ();
+  g_assert (edit);
+  gui_editor_show (edit);
+  if (tutorial_text == NULL)
+  {
+    tutorial_text = g_string_new (_("The tutorial file, asm-guide.txt, was not found. It should be present in directory - "));
+    g_string_append (tutorial_text, PACKAGE_DOC_DIR);  
+  }
+  gui_editor_set_text (edit, tutorial_text->str);
+  gui_editor_set_readonly (edit, TRUE);
+  gui_editor_set_show_line_numbers (edit, FALSE);
+  gtk_box_pack_end_defaults (GTK_BOX (cont), edit->scroll);
+  gtk_window_maximize (GTK_WINDOW (tutorial));
+  gtk_widget_show_all (tutorial);
+
+  /* clean up */
+  g_string_free (tutorial_text, TRUE);
+}
+
+void
+on_line_mark_activated (GtkSourceView *view, GtkTextIter *iter,
+                        GdkEventButton *event, gpointer editor)
+{
+  if ((event->button == 1) && (event->type == GDK_BUTTON_PRESS))
+  {
+    gint line_no = gtk_text_iter_get_line (iter);
+    gui_editor_toggle_mark_at_line ((GUIEditor *) editor, line_no);
+  }
+}
+
