@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,12 +15,14 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourceview.h>
 
 
 gboolean
@@ -37,6 +39,8 @@ G_MODULE_EXPORT void on_save_as1_activate (GtkMenuItem * menuitem, gpointer user
 
 G_MODULE_EXPORT void on_print_activate (GtkAction * menuitem, gpointer user_data);
 
+G_MODULE_EXPORT void on_font_select_activate (GtkAction * menuitem, gpointer user_data);
+
 G_MODULE_EXPORT void on_quit1_activate (GtkMenuItem * menuitem, gpointer user_data);
 
 G_MODULE_EXPORT void on_registers1_activate (GtkMenuItem * menuitem, gpointer user_data);
@@ -122,3 +126,16 @@ G_MODULE_EXPORT void on_start_but_open_clicked (GtkButton * button, gpointer use
 G_MODULE_EXPORT void on_start_but_close_clicked (GtkButton * button, gpointer user_data);
 
 G_MODULE_EXPORT void on_listing_save_clicked (GtkButton * button, gpointer user_data);
+
+G_MODULE_EXPORT void on_mem_list_start_clicked (GtkButton * button, gpointer user_data);
+
+G_MODULE_EXPORT void on_mem_list_start_changed (GtkEntry *entry, gpointer user_data);
+
+G_MODULE_EXPORT void on_io_list_start_clicked (GtkButton * button, gpointer user_data);
+
+G_MODULE_EXPORT void on_io_list_start_changed (GtkEntry * entry, gpointer user_data);
+
+G_MODULE_EXPORT void show_tutorial ();
+
+G_MODULE_EXPORT void on_line_mark_activated (GtkSourceView * view, GtkTextIter * iter,
+                                             GdkEventButton * event, gpointer editor);
