@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +31,9 @@
 #define MAX_ERR_MSG_SIZE 512
 
 static GString *file_name = NULL;
-//static GtkFileSelection *file_selection = NULL;
+static const gchar *default_dir = NULL;
+static gchar *last_open_save_dir = NULL;
+static GtkRecentManager *recent_manager = NULL;
 
 static void
 _set_file_name (gchar * name)
@@ -225,7 +228,11 @@ file_op_editor_save (void)
 	  if (gtk_dialog_run (GTK_DIALOG (file_selector)) == GTK_RESPONSE_ACCEPT)
 		{
 		  selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selector));
+		  if (recent_manager == NULL)
+		    recent_manager = gtk_recent_manager_get_default ();
+		  gtk_recent_manager_add_item (recent_manager, g_strconcat ("file://", selected_filename, NULL));
 		  is_saved = ori_save(selected_filename, TRUE);
+		  last_open_save_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_selector));
 		  g_free (selected_filename);
 		}
 	  else
@@ -252,6 +259,10 @@ file_op_editor_save_as (void)
 		{
 		  selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selector));
 		  is_saved = ori_save(selected_filename, TRUE);
+		  if (recent_manager == NULL)
+		    recent_manager = gtk_recent_manager_get_default ();
+		  gtk_recent_manager_add_item (recent_manager, g_strconcat ("file://", selected_filename, NULL));
+		  last_open_save_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_selector));
 		  g_free (selected_filename);
 		}
 	  else
@@ -280,7 +291,11 @@ file_op_editor_open (void)
 	{
 
 	  selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selector));
+	  if (recent_manager == NULL)
+	    recent_manager = gtk_recent_manager_get_default ();
+	  gtk_recent_manager_add_item (recent_manager, g_strconcat ("file://", selected_filename, NULL));
 	  ori_open(selected_filename, TRUE);
+	  last_open_save_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_selector));
 	  g_free (selected_filename);
 	}
 
@@ -303,6 +318,9 @@ file_op_listing_save (gchar * text)
 	{
 
 	  selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selector));
+	  if (recent_manager == NULL)
+	    recent_manager = gtk_recent_manager_get_default ();
+	  gtk_recent_manager_add_item (recent_manager, g_strconcat ("file://", selected_filename, NULL));
 
 	  fp = fopen (selected_filename, "w");
 	  if (fp == NULL)
@@ -314,6 +332,7 @@ file_op_listing_save (gchar * text)
 	  ret = fwrite (text, 1, strlen (text), fp);
 	  fclose (fp);
 
+	  last_open_save_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_selector));
 	  g_free (selected_filename);
 	}
 
@@ -329,7 +348,11 @@ create_file_dialog(const gchar *title,
 {
   GtkWidget *file_selector;
   GtkFileFilter *file_filter;
-  
+
+  if (default_dir == NULL)
+  {
+    default_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS);
+  }
   file_selector = gtk_file_chooser_dialog_new
 	(title, NULL,
 	 action,
@@ -337,6 +360,10 @@ create_file_dialog(const gchar *title,
 	 stock, GTK_RESPONSE_ACCEPT,
 	 NULL);
 
+  if (last_open_save_dir == NULL)
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(file_selector), default_dir);
+  else
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(file_selector), last_open_save_dir);
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER(file_selector), TRUE);
   
   file_filter = gtk_file_filter_new();
