@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #include "gui-editor.h"
@@ -193,6 +194,45 @@ gui_editor_toggle_mark (GUIEditor * self)
 	
 }
 
+void
+gui_editor_toggle_mark_at_line (GUIEditor * self, gint line_no)
+{
+  g_assert (self);
+
+  GtkTextIter line_start, line_end;
+  GSList *marker_list;
+  GtkSourceMark *marker;
+
+  /* get line bounds */
+  gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (self->buffer), &line_start, line_no);
+  line_end = line_start;
+  gtk_text_iter_forward_to_line_end (&line_end);
+
+  /* get the breakpoint markers already in the line */
+  marker_list = gtk_source_buffer_get_source_marks_at_line (self->buffer, line_no, MARKER_BREAKPOINT);
+
+  if (marker_list != NULL && g_slist_length(marker_list)!=0)
+	{
+	  /* markers were found, so delete them */
+	  gtk_source_buffer_remove_source_marks (self->buffer,  &line_start, &line_end, MARKER_BREAKPOINT);
+	}
+  else
+	{
+	  /* no marker found -> create one */
+	  marker = gtk_source_buffer_create_source_mark (self->buffer, NULL, MARKER_BREAKPOINT, &(line_start));
+	}
+  g_slist_free (marker_list);
+	
+}
+
+void
+gui_editor_set_margin_toggle_mark (GUIEditor * self)
+{
+  g_signal_connect ((gpointer) self->widget, "line-mark-activated",
+                    G_CALLBACK (on_line_mark_activated),
+                    self);
+}
+
 void
 gui_editor_clear_all_highlights (GUIEditor * self)
 {
@@ -277,12 +317,24 @@ gui_editor_set_readonly (GUIEditor * self, gboolean val)
   gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(self->widget), !val);
 }
 
+void
+gui_editor_set_show_line_numbers (GUIEditor * self, gboolean val)
+{
+  gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW(self->widget), val);
+}
+
 void
 gui_editor_grab_focus (GUIEditor * self)
 {
   gtk_widget_grab_focus (self->widget);
 }
 
+const gchar *
+gui_editor_get_font (GUIEditor *self)
+{
+  return self->current_font;
+}
+
 void
 gui_editor_set_font (GUIEditor *self, const gchar *font_name)
 {
@@ -296,6 +348,8 @@ gui_editor_set_font (GUIEditor *self, const gchar *font_name)
 
   gtk_widget_modify_font (GTK_WIDGET (self->widget), font_desc);
 
+  self->current_font = font_name;
+
   pango_font_description_free (font_desc);
 }
 
