@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 /*
@@ -38,6 +39,7 @@
 #include <gtksourceview/gtksourceprintcompositor.h>
 #include <gtksourceview/gtksourcestyleschememanager.h>
 #include <gtksourceview/gtksourcemark.h>
+#include "callbacks.h"
 
 #define DEFAULT_EDITOR_FONT   (const gchar*) "Monospace 12"
 #define MARKER_BREAKPOINT   (const gchar*) "breakpoint"
@@ -50,6 +52,8 @@ G_BEGIN_DECLS typedef struct
   GtkWidget *widget;
 
   GtkWidget *scroll;
+
+  const gchar* current_font;
 	
   GtkSourceBuffer *buffer;
 
@@ -82,6 +86,10 @@ void gui_editor_set_highlight (GUIEditor * self, guint line_no, gboolean set);
 
 void gui_editor_toggle_mark (GUIEditor * self);
 
+void gui_editor_toggle_mark_at_line (GUIEditor * self, gint line_no);
+
+void gui_editor_set_margin_toggle_mark (GUIEditor * self);
+
 void gui_editor_clear_all_highlights(GUIEditor *self);
 
 gboolean gui_editor_is_marked (GUIEditor *self, gint ln);
@@ -94,10 +102,14 @@ gint gui_editor_get_line (GUIEditor *self);
 
 void gui_editor_set_readonly (GUIEditor *self, gboolean val);
 
+void gui_editor_set_show_line_numbers (GUIEditor *self, gboolean val);
+
 void gui_editor_insert (GUIEditor *self, gchar *text);
 
 void gui_editor_grab_focus (GUIEditor *self);
 
+const gchar *gui_editor_get_font (GUIEditor *self);
+
 void gui_editor_set_font (GUIEditor *self, const gchar *font_name);
 
 void gui_editor_print (GUIEditor *self);
