@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -80,7 +81,7 @@ create_me (void)
   _add_column (view, C_ADDR, _("Stack Loc"));
   _add_column (view, C_NAME, _("Proc/Reg"));
   _add_column (view, C_VAL_HEX, _("Value"));
-  _add_column (view, C_VAL, _("Value(Decimal)"));
+  _add_column (view, C_VAL, g_strconcat(_("Value"), " (", _("Decimal"), ")", NULL));
 }
 
 void
