@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
 	
   This file is part of GNUSim8085.
 
@@ -15,7 +15,8 @@
 
   You should have received a copy of the GNU General Public License
   along with GNUSim8085; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -30,6 +31,8 @@
 #include "gui-list-data.h"
 #include "gui-list-stack.h"
 #include "gui-keypad.h"
+#include "gui-list-memory.h"
+#include "gui-list-io.h"
 #include "bridge.h"
 #include "callbacks.h"
 #include "file-op.h"
@@ -38,9 +41,16 @@ int
 main (int argc, char *argv[])
 {
   GtkWidget *statusbar;
+  gchar *localedir = LOCALEDIR;
+#ifdef WINDOWS
+  gchar *root = g_win32_get_package_installation_directory_of_module (NULL);
+  localedir = g_build_filename (root, "locale", NULL);
+  g_free (root);
+#endif
 
   setlocale (LC_ALL, "");
-  bindtextdomain (PACKAGE, LOCALEDIR);
+  bindtextdomain (PACKAGE, localedir);
+  bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
   gtk_init (&argc, &argv);
@@ -55,6 +65,10 @@ main (int argc, char *argv[])
   gui_list_data_attach_me ();
   gui_list_stack_attach_me ();
   gui_keypad_attach_me ();
+  gui_list_memory_attach_me ();
+  gui_list_memory_initialize ();
+  gui_list_io_attach_me ();
+  gui_list_io_initialize ();
   b_init ();
 
   /* Start with NEW file */
